==> mine-lights-2.3.1%2B1.17-sources.jar: megabytesme/minelights/config/LiveStatusEntry.java <==
package megabytesme.minelights.config;

import me.shedaniel.clothconfig2.api.AbstractConfigListEntry;
import net.minecraft.class_2561;
import net.minecraft.class_2585;
import net.minecraft.class_310;
import net.minecraft.class_364;
import net.minecraft.class_4587;
import net.minecraft.class_6379;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.function.Supplier;

public class LiveStatusEntry extends AbstractConfigListEntry<class_2561> {
    private final Supplier<class_2561> supplier;

    public LiveStatusEntry(String fieldName, Supplier<class_2561> supplier) {
        //? if >=1.19 {
        /*super(Text.literal(fieldName), false);
        *///?} else if >=1.16 {
        super(new class_2585(fieldName), false);
        //?} else {
        /*
        super(fieldName, false);
        */
        //?}
        this.supplier = supplier;
    }

    @Override
    public class_2561 getValue() { return supplier.get(); }

    @Override
    public Optional<class_2561> getDefaultValue() { return Optional.empty(); }

    @Override
    public void save() {}

    @Override
    public boolean isRequiresRestart() { return false; }

    @Override
    public void setRequiresRestart(boolean requiresRestart) {}

    @Override
    public int getItemHeight() { return 12; }

    @Override
    public List<? extends class_364> method_25396() {
        return Collections.emptyList();
    }

    //? if >=1.16.3 {
    @Override
    public List<? extends class_6379> narratables() {
        return Collections.emptyList();
    }
    //?}

    //? if >=1.20 {
    /*@Override
    public void render(DrawContext context, int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        Text current = supplier.get();
        context.drawText(MinecraftClient.getInstance().textRenderer, current, x + 2, y + 2, 0xFFFFFF, false);
    }
    *///?} else if >=1.16 {
    
    @Override
    public void render(class_4587 matrices, int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        class_2561 current = supplier.get();
        class_310.method_1551().field_1772.method_30883(matrices, current, x + 2, y + 2, 0xFFFFFF);
    }
    //?} else {
    /*
    @Override
    public void render(int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        Text current = supplier.get();
        MinecraftClient.getInstance().textRenderer.draw(current.asFormattedString(), (float) x + 2, (float) y + 2, 0xFFFFFF);
    }
    */
    //?}
}

==> mine-lights-2.3.3%2B1.16.2-sources.jar: megabytesme/minelights/config/LiveStatusEntry.java <==
package megabytesme.minelights.config;

import me.shedaniel.clothconfig2.api.AbstractConfigListEntry;
import net.minecraft.class_2561;
import net.minecraft.class_2585;
import net.minecraft.class_310;
import net.minecraft.class_364;
import net.minecraft.class_4587;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.function.Supplier;

public class LiveStatusEntry extends AbstractConfigListEntry<class_2561> {
    private final Supplier<class_2561> supplier;

    public LiveStatusEntry(String fieldName, Supplier<class_2561> supplier) {
        //? if >=1.19 {
        /*super(Text.literal(fieldName), false);
        *///?} else if >=1.16 {
        super(new class_2585(fieldName), false);
        //?} else {
        /*
        super(fieldName, false);
        */
        //?}
        this.supplier = supplier;
    }

    @Override
    public class_2561 getValue() { return supplier.get(); }

    @Override
    public Optional<class_2561> getDefaultValue() { return Optional.empty(); }

    @Override
    public void save() {}

    @Override
    public boolean isRequiresRestart() { return false; }

    @Override
    public void setRequiresRestart(boolean requiresRestart) {}

    @Override
    public int getItemHeight() { return 12; }

    @Override
    public List<? extends class_364> method_25396() {
        return Collections.emptyList();
    }

    //? if >=1.16.3 {
    /*@Override
    public List<? extends Selectable> narratables() {
        return Collections.emptyList();
    }
    *///?}

    //? if >=1.20 {
    /*@Override
    public void render(DrawContext context, int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        Text current = supplier.get();
        context.drawText(MinecraftClient.getInstance().textRenderer, current, x + 2, y + 2, 0xFFFFFF, false);
    }
    *///?} else if >=1.16 {
    
    @Override
    public void render(class_4587 matrices, int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        class_2561 current = supplier.get();
        class_310.method_1551().field_1772.method_30883(matrices, current, x + 2, y + 2, 0xFFFFFF);
    }
    //?} else {
    /*
    @Override
    public void render(int index, int y, int x,
                       int entryWidth, int entryHeight,
                       int mouseX, int mouseY,
                       boolean isHovered, float delta) {
        Text current = supplier.get();
        MinecraftClient.getInstance().textRenderer.draw(current.asFormattedString(), (float) x + 2, (float) y + 2, 0xFFFFFF);
    }
    */
    //?}
}
